==> ejc-settlementmanage-impl-3.0.0-20220812.091007-54-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookQuantityBasDeatilEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-收入明细表-工程量依据
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_quantity_bas")
public class SettlementBookQuantityBasDeatilEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="listing_code")
    private java.lang.String listingCode; // 清单编码
    @TableField(value="part_project_name")
    private java.lang.String partProjectName; // 分部分项工程名称
    @TableField(value="units")
    private java.lang.String units; // 单位
    @TableField(value="quantities")
    private java.lang.String quantities; // 工程量
    @TableField(value="calculation_process")
    private java.lang.String calculationProcess; // 计算过程
    @TableField(value="gist")
    private java.lang.String gist; // 依据
    @TableField(value="source")
    private java.lang.String source; // 来源
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 分部分项工程名称
     */
    public java.lang.String getPartProjectName() {
        return partProjectName;
    }

    /**
     * 分部分项工程名称
     */
    public void setPartProjectName(java.lang.String partProjectName) {
        this.partProjectName = partProjectName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 工程量
     */
    public java.lang.String getQuantities() {
        return quantities;
    }

    /**
     * 工程量
     */
    public void setQuantities(java.lang.String quantities) {
        this.quantities = quantities;
    }
    /**
     * 计算过程
     */
    public java.lang.String getCalculationProcess() {
        return calculationProcess;
    }

    /**
     * 计算过程
     */
    public void setCalculationProcess(java.lang.String calculationProcess) {
        this.calculationProcess = calculationProcess;
    }
    /**
     * 依据
     */
    public java.lang.String getGist() {
        return gist;
    }

    /**
     * 依据
     */
    public void setGist(java.lang.String gist) {
        this.gist = gist;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }
    
}

==> ejc-settlementmanage-impl-3.0.0-20221031.103951-96-sources.jar: com/ejianc/business/settlementmanage/bean/SettlementBookQuantityBasDeatilEntity.java <==
package com.ejianc.business.settlementmanage.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工程分包结算书子表-收入明细表-工程量依据
 * 
 * @author generator
 * 
 */
 @TableName("ejc_settlementmanage_settlement_book_quantity_bas")
public class SettlementBookQuantityBasDeatilEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private java.lang.Long sort; // 序号
    @TableField(value="listing_code")
    private java.lang.String listingCode; // 清单编码
    @TableField(value="part_project_name")
    private java.lang.String partProjectName; // 分部分项工程名称
    @TableField(value="units")
    private java.lang.String units; // 单位
    @TableField(value="quantities")
    private java.lang.String quantities; // 工程量
    @TableField(value="calculation_process")
    private java.lang.String calculationProcess; // 计算过程
    @TableField(value="gist")
    private java.lang.String gist; // 依据
    @TableField(value="source")
    private java.lang.String source; // 来源
    @TableField(value="section")
    private String section; // 区段
    @TableField(value="subitem_desc")
    private String subitemDesc; // 子目特征描述
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.Long getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.Long sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getListingCode() {
        return listingCode;
    }

    /**
     * 清单编码
     */
    public void setListingCode(java.lang.String listingCode) {
        this.listingCode = listingCode;
    }
    /**
     * 分部分项工程名称
     */
    public java.lang.String getPartProjectName() {
        return partProjectName;
    }

    /**
     * 分部分项工程名称
     */
    public void setPartProjectName(java.lang.String partProjectName) {
        this.partProjectName = partProjectName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnits() {
        return units;
    }

    /**
     * 单位
     */
    public void setUnits(java.lang.String units) {
        this.units = units;
    }
    /**
     * 工程量
     */
    public java.lang.String getQuantities() {
        return quantities;
    }

    /**
     * 工程量
     */
    public void setQuantities(java.lang.String quantities) {
        this.quantities = quantities;
    }
    /**
     * 计算过程
     */
    public java.lang.String getCalculationProcess() {
        return calculationProcess;
    }

    /**
     * 计算过程
     */
    public void setCalculationProcess(java.lang.String calculationProcess) {
        this.calculationProcess = calculationProcess;
    }
    /**
     * 依据
     */
    public java.lang.String getGist() {
        return gist;
    }

    /**
     * 依据
     */
    public void setGist(java.lang.String gist) {
        this.gist = gist;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }
}
